<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2006, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sourceforge.net>
	*	@version	CVS: $Id: main.lib.php,v 1.1.1.1 2006/02/20 21:52:23 xiam Exp $
	*	@link		http://www.gekkoware.org
	*/

	if (!defined("IN-GEKKO")) die("Get a life!");

	define("GEKKO_GALLERY_REL_DATADIR", "data/gallery");
	define("GEKKO_GALLERY_ABS_DATADIR", GEKKO_ROOT.GEKKO_GALLERY_REL_DATADIR);

	LoadLib (
		"file.lib.php"
	);

	mkworkdir(GEKKO_GALLERY_ABS_DATADIR);

	Class Gallery {
		/**
		* getPossibleGalleryStatus()
		* @returns: a human readable array of possible gallery status
		*/
		function getPossibleGalleryStatus() {
			$tmp = Array(_l("L_DISABLE"), _l("L_ENABLE"));
			return $tmp;
		}
		/**
		* guessMediaType(filename);
		* @returns: General file type based on extension
		*/
		function guessMediaType($file) {
			switch (file_extension($file)) {
				case "jpg": case "jpeg": case "gif": case "png": case "xpm": case "tiff":
					$type = "image";
				break;
				case "swf":
					$type = "flash";
				break;
				default:
					$type = "unknown";
				break;
			}
			return $type;
		}
		/**
		* getGalleries([gallery_id])
		* @returns: An array of galleries in which gallery_id can be placed
		*/
		function getGalleries($gallery_id = 0) {
			$return = Array();

			$db =& $GLOBALS["db"];

			$return[] = "("._l("L_MAIN").")";

			$q = $db->query("SELECT id, title, gallerylink
			FROM ".db_table("gallery")."
			".($gallery_id ? "WHERE id != '{$gallery_id}'" : "")."
			ORDER BY title ASC",
			__FILE__, __LINE__, true);

			if ($db->num_rows($q)) {
				while ($row = $db->fetch_row($q)) {
					saneHTML($row);
					$buff[$row["id"]] = $row;
				}

				foreach ($buff as $i => $b) {
					// asociating children galleries
					if (isset($buff[$b["gallerylink"]])) {
						$buff[$i]["title"] = $buff[$b["gallerylink"]]["title"]." &raquo; ".$buff[$i]["title"];
					}
				}

				usort($buff, create_function('$a,$b', 'return strcmp($a["title"], $b["title"]);'));

				while(list($i) = each($buff))
					$return[$buff[$i]["id"]] = $buff[$i]["title"];

			}
			return $return;
		}

		/**
		* deleteGallery(gallery_id)
		*/
		function deleteGallery($id) {
			$db =& $GLOBALS["db"];

			// deleting associated subgalleries
			$q = $db->query("SELECT id FROM ".db_table("gallery")."
			WHERE gallerylink = '{$id}'", __FILE__, __LINE__, true);
			while ($row = $GLOBALS["db"]->fetch_row($q)) {
				Gallery::deleteGallery($row["id"]);
			}

			// deleting associated items
			$q = $GLOBALS["db"]->query("SELECT id FROM ".db_table("gallery_item")."
			WHERE gallerylink = '{$id}'", __FILE__, __LINE__, true);
			while ($row = $db->fetch_row($q)) {
				Gallery::deleteItem($row["id"]);
			}

			// deleting thumbnail
			$q = $db->query("SELECT thumbnail FROM ".db_table("gallery")."
			WHERE id = '{$id}'", __FILE__, __LINE__, true);
			$r = $db->fetch_row($q);

			@unlink(GEKKO_ROOT.$row["thumbnail"]);

			slog("gallery: deleted gallery id='$id'", "actions", 1);

			return $db->query ("DELETE FROM ".db_table("gallery")." WHERE id='{$id}'", __FILE__, __LINE__, true);
		}
		/**
		* deleteItem(item_id);
		*/
		function deleteItem($id) {
			LoadLib ("comments");

			$db =& $GLOBALS["db"];

			// deleting comments
			Comments::deleteItems("gallery", $id);

			// deleting files associates with this item such as its thumbnail and media location
			$q = $db->query("SELECT thumbnail, mediaurl
			FROM ".db_table("gallery_item")." WHERE id = '{$id}'", __FILE__, __LINE__, true);
			$r = $db->fetch_row($q);

			@unlink(GEKKO_ROOT.$r["thumbnail"]);
			@unlink(GEKKO_ROOT.$r["mediaurl"]);

			slog("gallery: deleted galley item id='$id'", "actions", 1);

			return $db->query ("DELETE FROM ".db_table("gallery_item")." WHERE id='{$id}'", __FILE__, __LINE__, true);
		}

		/**
		* setGalleryStatus(gallery_id, status);
		*/
		function setGalleryStatus($id, $status) {
			slog("gallery: status of id='$id' changed to '$status'", "actions", 2);
			return $db->query ("UPDATE ".db_table("gallery")." SET status = '{$status}' WHERE id='{$id}'", __FILE__, __LINE__, true);
		}

		/**
		* countGalleries([gallery_id])
		* @returns: number of galleries associated to gallery_id. If gallery_id = 0,
		* then returns number of main galleries.
		*/
		function countGalleries($id = 0) {
			$db =& $GLOBALS["db"];
			$q = $db->query("SELECT id FROM ".db_table("gallery")."
			WHERE gallerylink = '{$id}'", __FILE__, __LINE__, true);
			return intval($db->num_rows($q));
		}

		/**
		* countItems([gallery_id]);
		* @returns: number or items associated to gallery_id
		*/
		function countItems($id = 0) {
			$db =& $GLOBALS["db"];

			$q = $db->query("SELECT id FROM ".db_table("gallery_item")."
			WHERE gallerylink = '{$id}'", __FILE__, __LINE__,
			true);

			return intval($db->num_rows($q));
		}
		/**
		* getAllowedGalleries([gallery]);
		* @returns: Allowed (sub)categories. If gallery < 0, then returns all possible galleries
		* where the current user is allowed to access.
		*/
		function getAllowedGalleries($gallery = 0) {
			$allowed = Array();

			$db =& $GLOBALS["db"];

			$q = $db->query("SELECT id, auth_access
			FROM ".db_table("gallery")."
			WHERE ".($gallery < 0 ? "" : "gallerylink = '{$gallery}' AND")." status = '1'",
			__FILE__, __LINE__, true);

			while ($row = $db->fetch_row($q)) {
				if (gauth($row["auth_access"])) {
					$allowed[] = $row["id"];
				}
			}

			return $allowed;
		}
		function allowComment($thread) {
			$db =& $GLOBALS["db"];

			// item existence
			$q = $db->query("SELECT gallerylink
			FROM ".db_table("gallery_item")."
			WHERE id = '{$thread}' AND allowcomments = '1'",
			__FILE__, __LINE__, true);
			$row = $db->fetch_row($q);

			// does this user have access to this item?
			$q = $db->query("SELECT auth_access FROM ".db_table("gallery")."
			WHERE id = '{$row["gallerylink"]}' AND status = '1'");
			$row = $db->fetch_row($q);

			return $db->num_rows($q) ? gauth($row["auth_access"]) : false;
		}
	}

?>